@@ -8,7 +8,7 @@ use LWP::UserAgent;
 use JSON qw( decode_json );
 use Params::Validate qw( validate SCALAR );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use constant URL => 'https://www.google.com/recaptcha/api/siteverify';
 
@@ -87,7 +87,11 @@ Google::reCAPTCHA - A simple lightweight implementation of Google's reCAPTCHA fo
     my $c = Google::reCAPTCHA->new( secret => 'secret_key' );
     
     # Verifying the user's response 
-    my $response = $c->siteverify( response => 'response_key', remoteip => '192.168.0.1' );
+    my $success = $c->siteverify( response => 'response_key', remoteip => '192.168.0.1' );
+    
+    if( $success ) {
+        # CAPTCHA was valid
+    }
 
 =head1 GETTING STARTED
 
@@ -101,7 +105,7 @@ https://www.google.com/recaptcha/admin/create
 
 Our constructor, will croak when invalid parameters are given.
 
-secret
+B<secret>
 
 Required. The shared key between your site and ReCAPTCHA.
 
@@ -109,17 +113,17 @@ Required. The shared key between your site and ReCAPTCHA.
 
 Request siteverify from Google reCAPTCHA API
 
-response
+B<response>
 
 Required. Form data containing g_captcha_response.
 
-remoteip
+B<remoteip>
 
 Optional. User's ip address.
 
 =head2 Errors
 
-Error code reference:
+B<Error code reference:>
 
 missing-input-secret    The secret parameter is missing.
 invalid-input-secret	The secret parameter is invalid or malformed.
@@ -128,15 +132,15 @@ invalid-input-response	The response parameter is invalid or malformed.
 
 =head1 Git repo
 
-https://bitbucket.org/tcorkran/google-recaptcha
+L<https://bitbucket.org/tcorkran/google-recaptcha>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =head1 AUTHOR
 
-Thomas Corkran C<< <thomas.corkran@endurance.com> >>
+Thomas Corkran C<< <thomascorkran@gmail.com> >>
 
 =head1 CONTRIBUTORS
 
@@ -147,7 +151,9 @@ Christopher Mevissen C<< <mev412@gmail.com> >>
 Matthew Green C<< <green.matt.na@gmail.com> >>
 
 This projects work was sponsored by Hostgator.com.
+
 L<http://www.hostgator.com>
+
 L<http://www.endurance.com>
 
 =head1 COPYRIGHT & LICENSE
